summaryrefslogtreecommitdiffstats
path: root/player/core.h
diff options
context:
space:
mode:
Diffstat (limited to 'player/core.h')
-rw-r--r--player/core.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/player/core.h b/player/core.h
index 9a9eb81852..0434c5cb64 100644
--- a/player/core.h
+++ b/player/core.h
@@ -438,9 +438,9 @@ typedef struct MPContext {
struct mp_ipc_ctx *ipc_ctx;
- pthread_mutex_t lock;
+ pthread_mutex_t abort_lock;
- // --- The following fields are protected by lock
+ // --- The following fields are protected by abort_lock
struct mp_cancel *demuxer_cancel; // cancel handle for MPContext.demuxer
// --- Owned by MPContext